Merge pull request #126 from flathub/dev-5.0-17210

Upgrade to 5.0-17210 to fix GPU texture decoding
This commit is contained in:
Carles Pastor Badosa 2022-08-20 14:42:13 +02:00 committed by GitHub
commit 360b9a6905
No known key found for this signature in database
GPG key ID: 4AEE18F83AFDEB23
3 changed files with 23 additions and 29 deletions

View file

@ -1,40 +1,34 @@
commit d4c899cede0743d40934ca11f83691cda72ff9dd From f2d3b349d8487cf0ee50b36ba024ac513d36f826 Mon Sep 17 00:00:00 2001
Author: Carles Pastor <cpbadosa@gmail.com> From: Carles Pastor <cpbadosa@gmail.com>
Date: Sat Apr 2 20:47:06 2022 +0200 Date: Sat, 20 Aug 2022 13:35:32 +0200
Subject: [PATCH] Detect we are running inside a flatpak sandbox
Detect when running inside a flatpak sandbox ---
Source/Core/UICommon/UICommon.cpp | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/Source/Core/UICommon/UICommon.cpp b/Source/Core/UICommon/UICommon.cpp diff --git a/Source/Core/UICommon/UICommon.cpp b/Source/Core/UICommon/UICommon.cpp
index cb857fd3c7..e3ddde24fb 100644 index 8d9dc2abb8..8a9d39a3d5 100644
--- a/Source/Core/UICommon/UICommon.cpp --- a/Source/Core/UICommon/UICommon.cpp
+++ b/Source/Core/UICommon/UICommon.cpp +++ b/Source/Core/UICommon/UICommon.cpp
@@ -309,24 +309,25 @@ void SetUserDirectory(std::string custom_path) @@ -348,7 +348,7 @@ void SetUserDirectory(std::string custom_path)
// We are on a non-Apple and non-Android POSIX system, there are 4 cases:
// 1. GetExeDirectory()/portable.txt exists
// -> Use GetExeDirectory()/User // -> Use GetExeDirectory()/User
// 2. $DOLPHIN_EMU_USERPATH is set // 2. $DOLPHIN_EMU_USERPATH is set
// -> Use $DOLPHIN_EMU_USERPATH // -> Use $DOLPHIN_EMU_USERPATH
// 3. ~/.dolphin-emu directory exists - // 3. ~/.dolphin-emu directory exists
// -> Use ~/.dolphin-emu // -> Use ~/.dolphin-emu
// 4. Default // 4. Default
// -> Use XDG basedir, see // -> Use XDG basedir, see
// http://standards.freedesktop.org/basedir-spec/basedir-spec-latest.html @@ -381,7 +381,7 @@ void SetUserDirectory(std::string custom_path)
{
user_path = home_path + "." DOLPHIN_DATA_DIR DIR_SEP; user_path = home_path + "." DOLPHIN_DATA_DIR DIR_SEP;
std::string exe_path = File::GetExeDirectory();
+ bool flatpak = File::Exists("/.flatpak-info"); - if (!File::Exists(user_path))
if (File::Exists(exe_path + DIR_SEP "portable.txt")) + if (File::Exists("/.flatpak-info") || !File::Exists(user_path))
{
user_path = exe_path + DIR_SEP "User" DIR_SEP;
}
- else if (env_path)
+ else if (env_path && !flatpak)
{
user_path = env_path;
}
- else if (!File::Exists(user_path))
+ else if (flatpak || !File::Exists(user_path))
{ {
const char* data_home = getenv("XDG_DATA_HOME"); const char* data_home = getenv("XDG_DATA_HOME");
std::string data_path = std::string data_path =
@@ -309,24 +309,25 @@ void SetUserDirectory(std::string custom_path) @@ -348,7 +348,7 @@ void SetUserDirectory(std::string custom_path)
// 1. GetExeDirectory()/portable.txt exists
// -> Use GetExeDirectory()/User // -> Use GetExeDirectory()/User
- // 2. $DOLPHIN_EMU_USERPATH is set // 2. $DOLPHIN_EMU_USERPATH is set
+ // 2. $DOLPHIN_EMU_USERPATH is set, and we're not in flatpak
// -> Use $DOLPHIN_EMU_USERPATH // -> Use $DOLPHIN_EMU_USERPATH
@@ -309,24 +309,25 @@ void SetUserDirectory(std::string custom_path) @@ -348,7 +348,7 @@ void SetUserDirectory(std::string custom_path)
// -> Use $DOLPHIN_EMU_USERPATH // -> Use $DOLPHIN_EMU_USERPATH
- // 3. ~/.dolphin-emu directory exists - // 3. ~/.dolphin-emu directory exists
+ // 3. ~/.dolphin-emu directory exists, and we're not in flatpak + // 3. ~/.dolphin-emu directory exists, and we're not in flatpak
// -> Use ~/.dolphin-emu // -> Use ~/.dolphin-emu
// 4. Default // 4. Default
--
2.37.1

View file

@ -22,7 +22,7 @@
<id>dolphin-emu.desktop</id> <id>dolphin-emu.desktop</id>
</provides> </provides>
<releases> <releases>
<release version="5.0-16793" date="2022-07-05"/> <release version="5.0-17210" date="2022-08-19"/>
</releases> </releases>
<url type="homepage">https://dolphin-emu.org</url> <url type="homepage">https://dolphin-emu.org</url>
<url type="help">https://forums.dolphin-emu.org</url> <url type="help">https://forums.dolphin-emu.org</url>

View file

@ -110,7 +110,7 @@ modules:
sources: sources:
- type: git - type: git
url: https://github.com/dolphin-emu/dolphin.git url: https://github.com/dolphin-emu/dolphin.git
commit: 3cd82b619388d0877436390093a6edc2319a6904 commit: 498c06b85af8c07d85229850646c276fa47047ea
x-checker-data: x-checker-data:
type: json type: json
url: https://dolphin-emu.org/update/latest/beta url: https://dolphin-emu.org/update/latest/beta